#script to read in data and analyse for Philosophical Transaction Royal Society B paper
#Pfeifer et al. 2022 'A systems approach framework for evaluating tree 
#restoration interventions for social and ecological outcomes in 
#rural tropical landscapes'


# ####(1) Install and load Packages ------------------------------------------------

gc() #clear space

necessary.packages<-c("devtools","rvest","MASS","pixmap","GGally",
                      "ggplot2","MuMIn","raster","graphics","jpeg","gamlss",
                      "R.utils","dplyr","reshape","rgdal","leaflet","mgcv",
                      "RColorBrewer","tidyverse","klaR","rJava","metafor",
                      "pixmap","png","colormap","patchwork","fmsb","hrbrthemes")

already.installed<-necessary.packages%in%installed.packages()[, 'Package']    #asks if the necessary packages are already installed in the library?
if (length(necessary.packages[!already.installed])>=1) {    #if any are NOT installed, download them now.
  install.packages(necessary.packages[!already.installed],dep=T)   #are the dependencies really necessary (there are lots!)?
}
sapply(necessary.packages,function(p) {require(p,quietly=T,character.only=T)})

#install.packages("rJava",dependencies = TRUE)
#Sys.setenv(JAVA_HOME="C:/Program Files (x86)/Java/jdk-10.0.1/")

# if (!requireNamespace("BiocManager", quietly = TRUE))
#   install.packages("BiocManager")
# BiocManager::install(c("graph", "Rgraphviz"), dep=TRUE)


# ####(2) Define some functions you may need --------------------------------------------------

stderr <- function(x, na.rm=FALSE) {
  if(is.matrix(x))
    apply(x,2,stderr,na.rm=rm)
  else if(is.vector(x))
    sqrt(var(x,na.rm=na.rm)/length1(x))
  else if(is.data.frame(x))
    sapply(x,stderr,na.rm=na.rm)
  else sqrt(var(as.vector(x),na.rm=na.rm)/length1(x))
}
remove_outliers <- function(x, na.rm = TRUE, ...) {
  qnt <- quantile(x, probs=c(.25, .75), na.rm = na.rm, ...)
  H <- 1.5 * IQR(x, na.rm = na.rm)
  y <- x
  y[x < (qnt[1] - H)] <- NA
  y[x > (qnt[2] + H)] <- NA
  y
}
length1 <- function (x) {
  length(!is.na(x)[!is.na(x)=="TRUE"])
}
Dsquared <- function(model = NULL, 
                     obs = NULL, 
                     pred = NULL, 
                     family = NULL, # needed only when 'model' not provided
                     adjust = FALSE, 
                     npar = NULL) { # needed only when 'model' not provided
  # version 1.4 (31 Aug 2015)
  
  model.provided <- ifelse(is.null(model), FALSE, TRUE)
  
  if (model.provided) {
    if (!("glm" %in% class(model))) stop ("'model' must be of class 'glm'.")
    if (!is.null(pred)) message("Argument 'pred' ignored in favour of 'model'.")
    if (!is.null(obs)) message("Argument 'obs' ignored in favour of 'model'.")
    obs <- model$y
    pred <- model$fitted.values
    
  } else { # if model not provided
    if (is.null(obs) | is.null(pred)) stop ("You must provide either 'obs' and 'pred', or a 'model' object of class 'glm'.")
    if (length(obs) != length(pred)) stop ("'obs' and 'pred' must be of the same length (and in the same order).")
    if (is.null(family)) stop ("With 'obs' and 'pred' arguments (rather than a model object), you must also specify one of two model family options: 'binomial' or 'poisson' (in quotes).")
    else if (!is.character(family)) stop ("Argument 'family' must be provided as character (i.e. in quotes: 'binomial' or 'poisson').")
    else if (length(family) != 1 | !(family %in% c("binomial", "poisson"))) stop ("'family' must be either 'binomial' or 'poisson' (in quotes).")
    
    if (family == "binomial") {
      if (any(!(obs %in% c(0, 1)) | pred < 0 | pred > 1)) stop ("'binomial' family implies that 'obs' data should be binary (with values 0 or 1) and 'pred' data should be bounded between 0 and 1.")
      link <- log(pred / (1 - pred))  # logit
    }  # end if binomial
    
    else if (family == "poisson") {
      if (any(obs %%1 != 0)) stop ("'poisson' family implies that 'obs' data should consist of whole numbers.")
      link <- log(pred)
    }  # end if poisson
    
    model <- glm(obs ~ link, family = family)
  }  # end if model not provided
  
  D2 <- (model$null.deviance - model$deviance) / model$null.deviance
  
  if (adjust) {
    if (model.provided) {
      n <- length(model$y)
      #p <- length(model$coefficients)
      p <- attributes(logLik(model))$df
    } else {
      if (is.null(npar)) stop ("Adjusted D-squared from 'obs' and 'pred' values (rather than a model object) requires specifying the number of parameters in the underlying model ('npar').")
      n <- length(na.omit(obs))
      p <- npar
    }  # end if model.provided else
    
    D2 <- 1 - ((n - 1) / (n - p)) * (1 - D2)
  }  # end if adjust
  
  return (D2)
}

# ####(3) Set colour schemes for figures -------------------
cols<-brewer.pal(8,"RdYlGn")
cols1<-brewer.pal(9,"Set1")
cols3<-brewer.pal(12,"Set3")
cols3biome<-c(cols3[12],cols3[1],cols3[7],cols1[3])
cols3vegtype<-c(cols1[9],cols3[4],cols3[6],cols3[8],cols1[3],cols3[7],cols3[11],cols3[12])
colcrops<-c(cols1[3],cols1[4],cols1[2],cols1[6])

# ####(4) specify working and output directories ---------------------------------------
#dirG<-getwd() #use the path to the datasets
dirG<-"C:/Users/mario/Marions_Works/AT_Papers_Work/PhilTransRoySocB_Paper/DataScript_Submission_PhilTrans"

dirGG<-paste(dirG,"Graphs_Overview",sep="/")
if (file.exists(dirGG)){
  cat("\n directory already exists")
} else {
  dir.create(file.path(dirGG))
}
dirGT<-paste(dirG,"Tables_Overview",sep="/")
if (file.exists(dirGT)){
  cat("\n directory already exists")
} else {
  dir.create(file.path(dirGT))
}

# ####(5) Read in the data frames for analyses/plotting-----------------------------------------
dirG #specify the working directory for the project
trades<-read.csv(paste(dirG,"tradeoffs_result_PlotsLocations.csv",sep="/"))

tt2<-read.csv(paste(dirG,"Yield_Plot.csv",sep="/"))
tt1<-read.csv(paste(dirG,"Yield_All.csv",sep="/"))

#create subset of data frames for crops data
tt_okra<-tt2[which(tt2$Okra_Weight_g.m2>0),]
tt_sugar<-tt2[which(tt2$Sugarcane_Weight_g>0),]
tt_maize<-tt2[which(tt2$Maize_Weight_g.m2>0),]
tt_okra$crop<-"Okra"
tt_maize$crop<-"Maize"
tt_sugar$crop<-"Sugarcane"
#trades_crops<-rbind(tt_okra[,c(1,8:18)],tt_sugar[,c(1,8:18)],tt_maize[c(1,8:18)])

trades$yield_okra<-tt_okra$Okra_Weight_g.m2[match(trades$plot,tt_okra$Site_ID)]
trades$yield_sugarcane<-tt_sugar$Sugarcane_Weight_g.m2[match(trades$plot,tt_sugar$Site_ID)]
trades$yield_maize<-tt_maize$Maize_Weight_g.m2[match(trades$plot,tt_sugar$Site_ID)]
trades$crop_weight_m2<-tt2$Harvest_Weight_g.m2[match(trades$plot,tt2$Site_ID)]
trades$crop_weight_m2[which(trades$yield_sugarcane>0)]<-trades$crop_weight_m2[which(trades$yield_sugarcane>0)]/10

trades$Vegetation_Type<-as.vector(as.character(trades$Vegetation_Type))
trades$Vegetation_Type<-ifelse(trades$Vegetation_Type=="maize_sugarcane","maize/sugarcane",trades$Vegetation_Type)
trades$Vegetation_Type<-as.factor(trades$Vegetation_Type)
trades$Biome<-ifelse(trades$Biome=="Plantation_Broad","Forest",trades$Biome)
trades$Biome<-ifelse(trades$Biome=="Cropland ","Cropland",trades$Biome)
trades$Biome<-ifelse(trades$Biome=="Grassland ","Grassland",trades$Biome)
trades$Biome<-ifelse(trades$Biome=="Forest ","Forest",trades$Biome)
trades$Biome<-ifelse(trades$Biome=="Woodland ","Woodland",trades$Biome)
trades$Biome<-factor(trades$Biome,levels=c("Cropland","Grassland","Woodland","Forest"))

#read in the data extracted from google earth engine
dfin_ind<-read.csv(paste(dirG,"dfinRSB_industryfarm_ge.csv",sep="/"))
dfin_sma<-read.csv(paste(dirG,"dfinRSB_smaholderfarm_ge.csv",sep="/"))
dfin_ecoplots<-read.csv(paste(dirG,"dfinRSB_locationplots_agrisys.csv",sep="/"))

#wellbeing dataset
soci<-read.csv(paste(dirG,"Wellbeing_dataset_LatLong_noNA.csv",sep="/"))

#soci$yield_staple


# #### (5.1) Plotting data for exploration --------------------------------

#use lllipop figures: order plot names first by fcover_value or
#species richness values and group by colur

trades$plot <- reorder(trades$plot, trades$fcover_point)

ggplot(trades, aes(x=plot, y=fcover_point)) +
  geom_segment( aes(x=plot, xend=plot, y=0, yend=fcover_point), color="skyblue") +
  geom_point( color="blue", size=4, alpha=0.6) +
  theme_light() +
  coord_flip() +
  theme(
    panel.grid.major.y = element_blank(),
    panel.border = element_blank(),
    axis.ticks.y = element_blank()
  )

ggplot(trades, aes(x=plot, y=Mam_Threat_P)) +
  geom_segment( aes(x=plot, xend=plot, y=0, yend=Mam_Threat_P), color="skyblue") +
  geom_point( color="blue", size=4, alpha=0.6) +
  theme_light() +
  coord_flip() +
  theme(
    panel.grid.major.y = element_blank(),
    panel.border = element_blank(),
    axis.ticks.y = element_blank()
  )

ggplot(trades, aes(x=plot, y=Bird_Threat_P)) +
  geom_segment( aes(x=plot, xend=plot, y=0, yend=Bird_Threat_P), color="skyblue") +
  geom_point( color="blue", size=4, alpha=0.6) +
  theme_light() +
  coord_flip() +
  theme(
    panel.grid.major.y = element_blank(),
    panel.border = element_blank(),
    axis.ticks.y = element_blank()
  )


# ####(5.2) Create Figure 3 -----------------------------------------------

###Create Fig 3A
tmin<-min(c(trades$tground_av_av,trades$tleaf_av),na.rm=T)
tmax<-max(c(trades$tground_av_av,trades$tleaf_av),na.rm=T)

cano<-ggplot(trades,aes(x=FCO,y=tground_av_av))+geom_point(size=4,aes(col=Biome))+
  stat_smooth(method="glm",formula = y ~ x)+
  ylim(c(tmin,tmax))+
theme_bw()+theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+
  guides(color=guide_legend(override.aes=list(fill=NA)),
         fill=guide_legend(title="Habitat type"))+
  scale_color_manual(values=cols3biome)+
  theme(axis.title.x=element_text(vjust=-0.35,size=25),axis.title.y=element_text(vjust= +0.9,size=25),
        axis.text.x=element_text(size=25,angle=-90),axis.text.y=element_text(size=20),
        legend.title = element_text(size=25, face="bold"),
        legend.text = element_text(size = 25))+
  ylab("T, ground; Celsius") +xlab("Canopy closure (%)")+
  theme(legend.title = element_blank(),legend.position=c(.8, .7)) 
nam.pb<-paste("Fig_3_A_FCO_Tground","tiff",sep=".")
cano
ggsave(cano,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=10,height=8)

#model summary stats underlying Fig 3A
M1<-gam(tground_av_av~s(FCO,k=2),data=trades)
M1g<-glm(tground_av_av~FCO,data=trades)
Dsquared(M1g)
summary(M1)
summary(M1g)
anova(M1,M1g)

#Creating Fig 3B
cano<-ggplot(trades,aes(x=FCO,y=tleaf_av))+geom_point(size=4,aes(col=Biome))+
  stat_smooth(method="gam",formula = y ~ s(x,k=2))+
  ylim(c(tmin,tmax))+
  theme_bw()+theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+
  guides(color=guide_legend(override.aes=list(fill=NA)),
         fill=guide_legend(title="Habitat type"))+
  scale_color_manual(values=cols3biome)+
  theme(axis.title.x=element_text(vjust=-0.35,size=25),axis.title.y=element_text(vjust= +0.9,size=25),
        axis.text.x=element_text(size=25,angle=-90),axis.text.y=element_text(size=20),
        legend.title = element_text(size=25, face="bold"),
        legend.text = element_text(size = 25))+
  ylab("T, leaves; Celsius") +xlab("Canopy closure (%)")+
  theme(legend.title = element_blank(),legend.position="none") 
cano
nam.pb<-paste("Fig_3_B_FCO_Tleaf","tiff",sep=".")
ggsave(cano,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=10,height=8)

#summary stats for Fig 3B models
M1<-gam(tleaf_av~s(FCO,k=2),data=trades)
M1g<-glm(tleaf_av~FCO,data=trades)
Dsquared(M1g)
summary(M1)
summary(M1g)
anova(M1,M1g,test="Chisq")

#create Fig 3 C
cano<-ggplot(trades,aes(x=FCO,y=fluor_av))+geom_point(size=4,aes(col=Biome))+
  stat_smooth(method="glm", formula = y ~ x)+
  theme_bw()+theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+
  guides(color=guide_legend(override.aes=list(fill=NA)),
         fill=guide_legend(title="Habitat type"))+
  scale_color_manual(values=cols3biome)+
  theme(axis.title.x=element_text(vjust=-0.35,size=25),axis.title.y=element_text(vjust= +0.9,size=25),
        axis.text.x=element_text(size=25,angle=-90),axis.text.y=element_text(size=20),
        legend.title = element_text(size=25, face="bold"),
        legend.text = element_text(size = 25))+
  ylab("Flurorescence")+xlab("Canopy closure (%)")+
  theme(legend.title = element_blank(),legend.position="none") 
nam.pb<-paste("Fig_3_C_FCO_FLUOR","tiff",sep=".")
cano
ggsave(cano,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=10,height=8)

#summary stats for models for Fig 3 C
M0<-glm(fluor_av~0,data=trades)
M1<-gam(fluor_av~s(FCO,k=2),data=trades)
M1g<-glm(fluor_av~FCO,data=trades)
Dsquared(M1g)
Dsquared(M1)
summary(M1)
summary(M1g)
anova(M1,M1g,test="Chisq")
anova(M1g,M0,test="Chisq")

#create Fig 3D
temp1<-tt_sugar[,c(1,14,18)]
names(temp1)<-c("plot","weight","crop")
temp1$weight<-temp1$weight/10
temp2<-tt_maize[,c(1,16,18)]
names(temp2)<-c("plot","weight","crop")
temp3<-tt_okra[,c(1,15,18)]
names(temp3)<-c("plot","weight","crop")
trades_crops<-rbind(temp1,temp2,temp3)
trades_crops$FCO<-trades$FCO[match(trades_crops$plot,trades$plot)]
trades_crops$treeN<-trades$TreesN[match(trades_crops$plot,trades$plot)]
trades_crops$treeSR<-trades$TreesSR[match(trades_crops$plot,trades$plot)]

library(Hmisc)
describe(trades_crops)
tapply(trades_crops$FCO,trades_crops$crop, summary) 
trades_crops$fluor_av <- trades$fluor_av[match(trades_crops$plot,trades$plot)]
trades_crops$tleaf_av <- trades$tleaf_av[match(trades_crops$plot,trades$plot)]


cano<-ggplot(trades_crops, aes(FCO,weight,col=crop)) + 
  geom_point(size=6)+
  theme_bw()+theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+
  guides(color=guide_legend(override.aes=list(fill=NA)),
         fill=guide_legend(title="Habitat type"))+
  scale_color_manual(values=colcrops[1:4])+
  theme(axis.title.x=element_text(vjust=-0.35,size=25),axis.title.y=element_text(vjust= +0.9,size=20),
        axis.text.x=element_text(size=25,angle=-90),axis.text.y=element_text(size=20),
        legend.title = element_text(size=25, face="bold"),
        legend.text = element_text(size = 25))+
  ylab("Crop Harvest g/m2")+xlab("Canopy closure (%)") +
  theme(legend.title = element_blank(),legend.position=c(0.6,0.2)) 
cano
nam.pb<-paste("Fig_3_D_FCO_Harvests","tiff",sep=".")
ggsave(cano,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=10,height=8)

# cano<-ggplot(trades_crops, aes(treeN,weight,col=crop)) + 
#   geom_point(size=6)+
#   theme_bw()+theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+
#   guides(color=guide_legend(override.aes=list(fill=NA)),
#          fill=guide_legend(title="Habitat type"))+
#   scale_color_manual(values=colcrops[1:4])+
#   theme(axis.title.x=element_text(vjust=-0.35,size=25),axis.title.y=element_text(vjust= +0.9,size=20),
#         axis.text.x=element_text(size=25,angle=-90),axis.text.y=element_text(size=20),
#         legend.title = element_text(size=25, face="bold"),
#         legend.text = element_text(size = 25))+
#   ylab("Crop Harvest g/m2")+xlab("Number of trees on plot") +
#   theme(legend.title = element_blank(),legend.position=c(0.7,0.75)) 
# cano
# nam.pb<-paste("Fig_3_D_Trees_Harvests","tiff",sep=".")
# ggsave(cano,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=10,height=8)

#summary stats for Fig 3D
M1<-gam(weight~s(FCO,k=2),data=trades_crops[which(trades_crops$crop=="Maize"),])
M1g<-glm(weight~FCO,data=trades_crops[which(trades_crops$crop=="Maize"),])
Dsquared(M1g)
summary(M1)
summary(M1g)
anova(M1,M1g,test="Chisq")

M0<-glm(weight~0,data=trades_crops[which(trades_crops$crop=="Maize"),])
anova(M1g,M0,test="Chisq")


# ####(5.3) Summary statistics Table 1 ------------------------------------
names(trades)
vars_1<-c("tground_av_av","tleaf_av","fluor_av","FCO","ndvi_mean1920","Biome")
trades_test<-trades[,vars_1]
trades_test<-na.omit(trades_test)
names(trades_test)<-c("tground","tleaf","fluor","fco","ndvi","Biome")

library(doBy)
summaryBy(fco~Biome,data=trades_test,FUN=c(length,mean,sd,median))
summary(aov(trades_test$fco~trades_test$Biome))
TukeyHSD(aov(trades_test$fco~trades_test$Biome))
plot(fco~Biome,data=trades_test)

summaryBy(tground~Biome,data=trades_test,FUN=c(length,mean,sd,median))
summary(aov(trades_test$tground~trades_test$Biome))
TukeyHSD(aov(trades_test$tground~trades_test$Biome))
plot(tground~Biome,data=trades_test)

summaryBy(tleaf~Biome,data=trades_test,FUN=c(length,mean,sd,median))
summary(aov(trades_test$tleaf~trades_test$Biome))
TukeyHSD(aov(trades_test$tleaf~trades_test$Biome))
plot(tleaf~Biome,data=trades_test)

summaryBy(fluor~Biome,data=trades_test,FUN=c(length,mean,sd,median))
summary(aov(trades_test$fluor~trades_test$Biome))
TukeyHSD(aov(trades_test$fluor~trades_test$Biome))
plot(fluor~Biome,data=trades_test)

vars_2<-c("FCO","tground_av_av","tleaf_av","fluor_av","Mam_SRC3",
          "Bird_SRC3","Mam_Threat_P","Bird_Threat_P",
          "Mam_SeedC2","Bird_SeedC2","Biome")
trades_test1<-trades[,vars_2]
trades_test1<-na.omit(trades_test1)
names(trades_test1)<-c("Canopy closure","T, ground",
                       "T, leaf","Fluorescence",
                       "Mammals, H","Birds, H",
                       "Mammals, T","Birds, T",
                       "Mammals, HSP","Birds, HSP",
                       "Habitattype")


summaryBy(Bird_SRC3~Biome,data=trades,FUN=c(length,mean,sd,median))
summaryBy(Bird_SRC2~Biome,data=trades,FUN=c(length,mean,sd,median))
summaryBy(Bird_SRC1~Biome,data=trades,FUN=c(length,mean,sd,median))
summaryBy(Bird_Threat_P~Biome,data=trades,FUN=c(length,mean,sd,median))

summaryBy(Mam_SRC3~Biome,data=trades,FUN=c(length,mean,sd,median))
summaryBy(Mam_SRC2~Biome,data=trades,FUN=c(length,mean,sd,median))
summaryBy(Mam_SRC1~Biome,data=trades,FUN=c(length,mean,sd,median))
summaryBy(Mam_Threat_P~Biome,data=trades,FUN=c(length,mean,sd,median))
summaryBy(Conflict_risk~Biome,data=trades,FUN=c(length,mean,sd,median))

summaryBy(Bird_SeedC2~Biome,data=trades,FUN=c(length,mean,sd,median))
summaryBy(Mam_SeedC2~Biome,data=trades,FUN=c(length,mean,sd,median))

summary(aov(trades$Mam_SRC3~trades$Biome))
TukeyHSD(aov(trades$Mam_SRC3~trades$Biome))
plot(Mam_SRC3~Biome,data=trades)

summary(aov(trades$Mam_SRC2~trades$Biome))
TukeyHSD(aov(trades$Mam_SRC2~trades$Biome))
plot(Mam_SRC2~Biome,data=trades)

summary(aov(trades$Bird_SRC3~trades$Biome))
TukeyHSD(aov(trades$Bird_SRC3~trades$Biome))
plot(Bird_SRC3~Biome,data=trades)

summary(aov(trades$Mam_Threat_P~trades$Biome))
TukeyHSD(aov(trades$Mam_Threat_P~trades$Biome))
plot(Mam_Threat_P~Biome,data=trades)

summary(aov(trades$Bird_Threat_P~trades$Biome))
TukeyHSD(aov(trades$Bird_Threat_P~trades$Biome))
plot(Bird_Threat_P~Biome,data=trades)

summary(aov(trades$Mam_SeedC2~trades$Biome))
TukeyHSD(aov(trades$Mam_SeedC2~trades$Biome))
plot(Mam_SeedC2~Biome,data=trades)

summary(aov(trades$Bird_SeedC2~trades$Biome))
TukeyHSD(aov(trades$Bird_SeedC2~trades$Biome))
plot(Bird_SeedC2~Biome,data=trades)

#create a parallel cooridnate plot to visualise diffrences between habitat types
# Fig_4<-trades_test1 %>% 
#   ggparcoord(
#     columns = 1:10, groupColumn = 11, 
#     showPoints = TRUE, 
#     scale="center",
#     title = "Parallel Coordinate Plot, biodiversity & structure",
#     alphaLines = 0.5
#   ) + 
#   #scale_color_viridis(discrete=TRUE) +
#   theme_ipsum()+
#   scale_color_manual(values=cols3biome)+
#   theme(axis.text.x=element_text(angle=45,hjust=1,size=20),
#         legend.title = element_text(size=20, face="bold"),
#         axis.title.x=element_text(size=25),
#         axis.text.y=element_text(size=20),
#         axis.title.y=element_text(size=25),
#         legend.text = element_text(size = 20))+
#   geom_line(size=1.5)+
#   labs(color = "Habitat type")   
# Fig_4
# nam.pb<-paste("Fig_ParallelPlot_Mix_all","tiff",sep=".")
# ggsave(Fig_4,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=15,height=8)
# 
# Fig_4<-trades_test1 %>% 
#   ggparcoord(
#     columns = 1:10, groupColumn = 11, 
#     showPoints = TRUE, 
#     scale="std",
#     title = "Parallel Coordinate Plot, biodiversity & structure",
#     alphaLines = 0.5
#   ) + 
#   #scale_color_viridis(discrete=TRUE) +
#   theme_ipsum()+
#   scale_color_manual(values=cols3biome)+
#   theme(axis.text.x=element_text(angle=45,hjust=1,size=20),
#         legend.title = element_text(size=20, face="bold"),
#         axis.title.x=element_text(size=25),
#         axis.text.y=element_text(size=20),
#         axis.title.y=element_text(size=25),
#         legend.text = element_text(size = 20))+
#   geom_line(size=1.5)+
#   labs(color = "Habitat type")   
# Fig_4
# nam.pb<-paste("Fig_ParallelPlot_Mix_all_normalisescale","tiff",sep=".")
# ggsave(Fig_4,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=15,height=8)
# 


# ####(5.4) Cropland plots - lollipop plots ------------------------------------------------

#for cropland plots only
trades_c<-droplevels(trades[which(trades$Biome=="Cropland"),])
trades_c$plot <- reorder(trades_c$plot, trades_c$ndvi_mean1920)
trades$ID <- reorder(trades$ID, trades$FCO)
trades_c$ID<-rownames(trades_c)

##doubel check on the use of ndvi as suitable metrics in cropland yield
##some explorative visualising
ggplot(trades_c,aes(yield_sugarcane,ndvi_mean1920))+geom_point()
ggplot(trades_c,aes(yield_maize,ndvi_mean1920))+geom_point()
ggplot(trades_c,aes(yield_okra,ndvi_mean1920))+geom_point()

#for plots without trees, NDVI measured from space correlates well with 
#sugarcane crop yield but not with others
#subset to crop plots without trees present on plots
trades_cs<-trades_c[which(trades_c$TreesN==0),]
ggplot(trades_cs,aes(yield_sugarcane,ndvi_mean1920))+geom_point()
ggplot(trades_cs,aes(yield_maize,ndvi_mean1920))+geom_point()
ggplot(trades_cs,aes(yield_okra,ndvi_mean1920))+geom_point()
ggplot(trades_cs[which(trades_cs$Vegetation_Type=="sugarcane"),],aes(disforestlandsat,ndvi_mean1920))+geom_point()


# Fig_y<-ggplot(trades_c[which(trades_c$yield_sugarcane>0),], aes(x=ID, y=yield_sugarcane)) +
#   geom_segment( aes(x=ID, xend=ID, y=0, yend=yield_sugarcane,col=factor(Vegetation_Type))) +
#   geom_point( size=4, alpha=0.6,aes(col=factor(Vegetation_Type))) +
#   theme_light() +
#   coord_flip() +
#   theme(
#     panel.grid.major.y = element_blank(),
#     panel.border = element_blank(),
#     axis.ticks.y = element_blank(),
#     axis.title=element_text(size=20),
#     axis.text.y=element_text(size=3),
#     axis.text.x=element_text(size=15),
#   )+
#   guides(color=guide_legend(override.aes=list(fill=NA)))+
#   scale_color_manual(values=cols3vegtype)
# Fig_y

#more visuals for crops: parallel coorindate plots
keep.var<-c("Bird_Threat_P","Bird_SRC3","Bird_SeedC2","FCO","fluor_av","tground_av_av","yield_sugarcane")
keep.var1<-c("Bird_Threat_P","Bird_SRC3","Bird_SeedC2","FCO","fluor_av","tground_av_av","yield_okra")
keep.var2<-c("Bird_Threat_P","Bird_SRC3","Bird_SeedC2","FCO","fluor_av","tground_av_av","yield_maize")

trsugar<-trades_c[which(trades_c$yield_sugarcane>0),keep.var]
trokra<-trades_c[which(trades_c$yield_okra>0),keep.var1]
trmaize<-trades_c[which(trades_c$yield_maize>0),keep.var2]
rownames(trsugar)<-trades_c$plot[which(trades_c$yield_sugarcane>0)]
rownames(trokra)<-trades_c$plot[which(trades_c$yield_okra>0)]
rownames(trmaize)<-trades_c$plot[which(trades_c$yield_maize>0)]

names(trsugar)[c(6,7)]<-c("tground","yield")
names(trokra)[c(6,7)]<-c("tground","yield")
names(trmaize)[c(6,7)]<-c("tground","yield")
trsugar$ID<-rownames(trsugar)
trokra$ID<-rownames(trokra)
trmaize$ID<-rownames(trmaize)

# figy<-trsugar %>% 
#   ggparcoord(
#     columns = 1:7, groupColumn = 8, 
#     showPoints = TRUE, 
#     title = "Parallel Coordinate Plot, sugarcane plots",
#     alphaLines = 0.5
#   ) + 
#   #scale_color_viridis(discrete=TRUE) +
#   theme_ipsum()+
#   theme(legend.position = "None",
#     axis.text.x=element_text(angle=45,hjust=1,size=20),
#         legend.title = element_text(size=20, face="bold"),
#         axis.title.x=element_text(size=25),
#         axis.text.y=element_text(size=20),
#         axis.title.y=element_text(size=25),
#         legend.text = element_text(size = 20))+
#   geom_line(size=1)
# figy
# nam.pb<-paste("Fig_ParallelPlot_sugarcane","tiff",sep=".")
# ggsave(figy,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=15,height=8)

# figx<-trokra %>% 
#   ggparcoord(
#     columns = 1:7, groupColumn = 8, 
#     showPoints = TRUE, 
#     title = "Parallel Coordinate Plot, okra plots",
#     alphaLines = 0.5
#   ) + 
#   #scale_color_viridis(discrete=TRUE) +
#   theme_ipsum()+
#   theme(legend.position = "None",
#         axis.text.x=element_text(angle=45,hjust=1,size=20),
#         legend.title = element_text(size=20, face="bold"),
#         axis.title.x=element_text(size=25),
#         axis.text.y=element_text(size=20),
#         axis.title.y=element_text(size=25),
#         legend.text = element_text(size = 20))+
#   geom_line(size=1)
# figx
# nam.pb<-paste("Fig_ParallelPlot_okra","tiff",sep=".")
# ggsave(figx,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=15,height=8)
# 
# 
# figz<-trmaize %>% 
#   ggparcoord(
#     columns = 1:7, groupColumn = 8, 
#     showPoints = TRUE, 
#     title = "Parallel Coordinate Plot, maize plots",
#     alphaLines = 0.5
#   ) + 
#   #scale_color_viridis(discrete=TRUE) +
#   theme_ipsum()+
#   theme(legend.position = "None",
#         axis.text.x=element_text(angle=45,hjust=1,size=20),
#         legend.title = element_text(size=20, face="bold"),
#         axis.title.x=element_text(size=25),
#         axis.text.y=element_text(size=20),
#         axis.title.y=element_text(size=25),
#         legend.text = element_text(size = 20))+
#   geom_line(size=1)
# figz
# nam.pb<-paste("Fig_ParallelPlot_maize","tiff",sep=".")
# ggsave(figz,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=15,height=8)

# ####(5.5) Create S7 Figure: cropland ecological plots ----------------------------------------------
trades_c$ID <- reorder(trades_c$ID, trades_c$ndvi_mean1920)

#create S7 Figure panels
Fig_5_d<-ggplot(trades_c) +
  geom_segment( aes(x=ID, xend=ID, y=Bird_SRC3, yend=Bird_SRC3_Scen1,color="red",size=3)) +
  geom_point(alpha=1, aes(x=ID, y=Bird_SRC3), color="black", size=6 ) +
  geom_point(alpha=0.6, aes(x=ID, y=Bird_SRC3_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=25),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=4),
    axis.text.x=element_text(size=25),
  )+
  xlab("ID (sorted by NDVI mean 2019/20)")+
  ylab("Probability of high number of species")+
  theme(legend.title = element_blank(),legend.position="none") +
  ggtitle("High number of bird species")
Fig_5_d
nam.pb<-paste("Fig_S7_BirdsSC3_Scen4_SortedbyNDVI","tiff",sep=".")
ggsave(Fig_5_d,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=8,height=8)

colors <- c("Baseline" = "black", "Scenario" = "orange", "TChange" = "red")

Fig_5_f<-ggplot(trades_c) +
  geom_segment( aes(x=ID, xend=ID, y=Bird_Threat_P, yend=Bird_Threat_P_Scen1,color="TChange"),size=3) +
  geom_point(alpha=1, aes(x=ID, y=Bird_Threat_P, col="Baseline"), size=6 ) +
  geom_point(alpha=0.5, aes(x=ID, y=Bird_Threat_P_Scen1, col="Scenario"), size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=25),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=4),
    axis.text.x=element_text(size=25),
  )+
  xlab("ID (sorted by NDVI mean 2019/20)")+
  ylab("Probability of presence")+
  theme(legend.title = element_blank(),legend.position="none") +
  ggtitle("Presence of threatened birds")
Fig_5_f
test<-Fig_5_f+scale_colour_manual(values=c("black", "orange","red"), name="Before/After Restoration",labels=c("Baseline", "Scenario", "Change"))
test<-test+ theme(legend.title = element_blank(),legend.text = element_text (size = 28),legend.position=c(0.8,0.72)) 
test<-test+guides(color = guide_legend(override.aes = list(linetype=c(rep("blank",2),"solid"),                                                           shape = c(19,19,NA))))
test
nam.pb<-paste("Fig_S7_ThreatBirds_Scen4_SortedbyNDVI","tiff",sep=".")
ggsave(test,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=8,height=8)

#summary stats
rm(temp)
temp<-round(trades_c$Bird_SRC3_Scen1-trades_c$Bird_SRC3,2)
length(which(trades_c$Bird_SRC3>0.5))
length(which(temp<0))
length(which(temp>0))
mean(temp[which(temp<0)])
mean(temp[which(temp>0)])
rm(temp)
temp<-round(trades_c$Mam_SRC3_Scen1-trades_c$Mam_SRC3,2)
length(which(trades_c$Mam_SRC3>0.5))
length(which(temp<0))
length(which(temp>0))
mean(temp[which(temp<0)])
mean(temp[which(temp>0)])
rm(temp)
temp<-round(trades_c$Mam_Threat_P_Scen1-trades_c$Mam_Threat_P,2)
length(which(trades_c$Mam_Threat_P>0.5))
length(which(temp<0))
length(which(temp>0))
mean(temp[which(temp<0)])
mean(temp[which(temp>0)])
rm(temp)
temp<-round(trades_c$Bird_SeedC2_Scen1-trades_c$Bird_SeedC2,2)
length(which(trades_c$Bird_SeedC2>0.6))
length(which(temp<0))
length(which(temp>0))
mean(temp[which(temp<0)])
mean(temp[which(temp>0)])
rm(temp)
temp<-round(trades_c$Bird_Threat_P_Scen1-trades_c$Bird_Threat_P,2)
length(which(trades_c$Bird_Threat_P>0.4))
length(which(temp<0))
length(which(temp>0))
mean(temp[which(temp<0)])
mean(temp[which(temp>0)])
rm(temp)
temp<-round(trades_c$Bird_SeedC2_Scen1-trades_c$Bird_SeedC2,2)
length(which(trades_c$Bird_SeedC2>0.6))
length(which(temp<0))
length(which(temp>0))
mean(temp[which(temp<0)])
mean(temp[which(temp>0)])

rm(temp)
temp<-round(trades_c$Mam_SeedC2_Scen1-trades_c$Mam_SeedC2,2)
length(which(trades_c$Mam_SeedC2<0.1))
length(which(temp<0))
length(which(temp>0))
mean(temp[which(temp<0)])
mean(temp[which(temp>0)])

rm(temp)
temp<-round(trades_c$Bird_Carni_P_Scen1-trades_c$Bird_Carni_P,2)
length(which(trades_c$Bird_Carni_P> 0.4))
length(which(temp<0))
length(which(temp>0))
mean(temp[which(temp<0)])
mean(temp[which(temp>0)])

temp<-round(trades_c$Mam_CarniP_Scen1-trades_c$Mam_CarniP,2)
length(which(trades_c$Mam_CarniP> 0.6))
length(which(temp<0))
length(which(temp>0))
mean(temp[which(temp<0)])
mean(temp[which(temp>0)])

temp<-round(trades_c$Conflict_risk_Scen1-trades_c$Conflict_risk,2)
length(which(temp<0))
length(which(temp>0))
mean(temp[which(temp<0)])
mean(temp[which(temp>0)])


Fig_5_h<-ggplot(trades_c) +
  geom_segment( aes(x=ID, xend=ID, y=Bird_SeedC2, yend=Bird_SeedC2_Scen1,color="red",size=3)) +
  geom_point(alpha=1, aes(x=ID, y=Bird_SeedC2), color="black", size=6 ) +
  geom_point(alpha=0.6, aes(x=ID, y=Bird_SeedC2_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=25),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=4),
    axis.text.x=element_text(size=25),
  )+
  xlab("ID (sorted by NDVI mean 2019/20)")+
  ylab("Probability of high number of species")+
  theme(legend.title = element_blank(),legend.position="none") +
  ggtitle("High N of seed & plant eating bird species")
Fig_5_h
nam.pb<-paste("Fig_S7_Birds_Seed_Scen4_SortedbyNDVI","tiff",sep=".")
ggsave(Fig_5_h,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=8,height=8)

colors <- c("Baseline" = "black", "Scenario" = "orange", "TChange" = "red")

Fig_5_hm<-ggplot(trades_c) +
  geom_segment( aes(x=ID, xend=ID, y=Mam_SeedC2, yend=Mam_SeedC2_Scen1,color="TChange"),size=3) +
  geom_point(alpha=1, aes(x=ID, y=Mam_SeedC2, col="Baseline"), size=6 ) +
  geom_point(alpha=0.5, aes(x=ID, y=Mam_SeedC2_Scen1, col="Scenario"), size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=25),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=4),
    axis.text.x=element_text(size=25),
  )+
  xlab("ID (sorted by NDVI mean 2019/20)")+
  ylab("Probability of high number of species")+
  theme(legend.title = element_blank(),legend.position="none") +
  ggtitle("High N of seed & plant eating mammal species")
Fig_5_hm
test<-Fig_5_hm+scale_colour_manual(values=c("black", "orange","red"), name="Before/After Restoration",labels=c("Baseline", "Scenario", "Change"))
test<-test+ theme(legend.title = element_blank(),legend.text = element_text (size = 28),legend.position=c(0.8,0.72)) 
test<-test+guides(color = guide_legend(override.aes = list(linetype=c(rep("blank",2),"solid"),
                                                           shape = c(19,19,NA))))
test

nam.pb<-paste("Fig_S7_Mams_Seed_Scen4_SortedbyNDVI","tiff",sep=".")
ggsave(test,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=8,height=8)

Fig_5_j<-ggplot(trades_c) +
  geom_segment( aes(x=ID, xend=ID, y=Conflict_risk, yend=Conflict_risk_Scen1,color="red"),size=3) +
  geom_point(alpha=1, aes(x=ID, y=Conflict_risk), color="black", size=6 ) +
  geom_point(alpha=0.6, aes(x=ID, y=Conflict_risk_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=25),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=4),
    axis.text.x=element_text(size=25),
  )+
  xlab("ID (sorted by NDVI mean 2019/20)")+
  ylab("Probability of crop raiding incident")+
  theme(legend.title = element_blank(),legend.position="none") +
  ggtitle("Scenario, Crop - Elephant conflict risk")
Fig_5_j
nam.pb<-paste("Fig_S7_HWC_Scen4_SortedbyNDVI","tiff",sep=".")
ggsave(Fig_5_j,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=8,height=8)

Fig_5_l<-ggplot(trades_c) +
  geom_segment( aes(x=ID, xend=ID, y=Mam_SRC3, yend=Mam_SRC3_Scen1,color="red",size=3)) +
  geom_point(alpha=1, aes(x=ID, y=Mam_SRC3), color="black", size=6 ) +
  geom_point(alpha=0.6, aes(x=ID, y=Mam_SRC3_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=25),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=4),
    axis.text.x=element_text(size=25),
  )+
  xlab("ID (sorted by NDVI mean 2019/20)")+
  ylab("Probability of high number of mammals")+
  theme(legend.title = element_blank(),legend.position="none") +
  ggtitle("High number of mammal species")
Fig_5_l
nam.pb<-paste("Fig_S7_MamSC3_Scen4_SortedbyNDVI","tiff",sep=".")
ggsave(Fig_5_l,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=8,height=8)

Fig_5_lm<-ggplot(trades_c) +
  geom_segment( aes(x=ID, xend=ID, y=Mam_Threat_P, yend=Mam_Threat_P_Scen1,color="red",size=3)) +
  geom_point(alpha=1, aes(x=ID, y=Mam_Threat_P), color="black", size=6 ) +
  geom_point(alpha=0.6, aes(x=ID, y=Mam_Threat_P_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=25),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=4),
    axis.text.x=element_text(size=25),
  )+
  xlab("ID (sorted by NDVI mean 2019/20)")+
  ylab("Probability of presence")+
  theme(legend.title = element_blank(),legend.position="none") +
  ggtitle("Presence of threatened mammals")
Fig_5_lm
nam.pb<-paste("Fig_S7_ThreatMam_Scen4_SortedbyNDVI","tiff",sep=".")
ggsave(Fig_5_lm,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=8,height=8)


Fig_5_p<-ggplot(trades_c) +
  geom_segment( aes(x=ID, xend=ID, y=Bird_InsC2, yend=Bird_InsC2_Scen1,color="red",size=3)) +
  geom_point(alpha=1, aes(x=ID, y=Bird_InsC2), color="black", size=6 ) +
  geom_point(alpha=0.6, aes(x=ID, y=Bird_InsC2_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=25),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=4),
    axis.text.x=element_text(size=25),
  )+
  xlab("ID (sorted by NDVI mean 2019/20)")+
  ylab("Probability of high number of species")+
  theme(legend.title = element_blank(),legend.position="none") +
  ggtitle("High N of invertebrate feeding bird species")
Fig_5_p
nam.pb<-paste("Fig_S7_BirdInsecteating_Scen4_SortedbyNDVI","tiff",sep=".")
ggsave(Fig_5_p,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=8,height=8)

Fig_5_pm<-ggplot(trades_c) +
  geom_segment( aes(x=ID, xend=ID, y=Mam_CarniP, yend=Mam_CarniP_Scen1,color="red",size=3)) +
  geom_point(alpha=1, aes(x=ID, y=Mam_CarniP), color="black", size=6 ) +
  geom_point(alpha=0.6, aes(x=ID, y=Mam_CarniP_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=25),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=4),
    axis.text.x=element_text(size=25),
  )+
  xlab("ID (sorted by NDVI mean 2019/20)")+
  ylab("Probability of presence")+
  theme(legend.title = element_blank(),legend.position="none") +
  ggtitle("Presence of carnivorous mammals")
Fig_5_pm
nam.pb<-paste("Fig_S7_MamCarniv_Scen4_SortedbyNDVI","tiff",sep=".")
ggsave(Fig_5_pm,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=8,height=8)

Fig_5_pb<-ggplot(trades_c) +
  geom_segment( aes(x=ID, xend=ID, y=Bird_Carni_P, yend=Bird_Carni_P_Scen1,color="red",size=3)) +
  geom_point(alpha=1, aes(x=ID, y=Bird_Carni_P), color="black", size=6 ) +
  geom_point(alpha=0.6, aes(x=ID, y=Bird_Carni_P_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=25),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=4),
    axis.text.x=element_text(size=25),
  )+
  xlab("ID (sorted by NDVI mean 2019/20)")+
  ylab("Probability of presence")+
  theme(legend.title = element_blank(),legend.position="none") +
  ggtitle("Presence of carnivorous birds")
Fig_5_pb
nam.pb<-paste("Fig_S7_BirdCarniv_Scen4_SortedbyNDVI","tiff",sep=".")
ggsave(Fig_5_pb,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=8,height=8)

# ####(5.6) Create S8 Figure ----------------------------------------------

tra_ag<-aggregate(cbind(Bird_SRC3,Bird_SRC3_Scen1,Mam_SRC3,Mam_SRC3_Scen1,Mam_Threat_P,Mam_Threat_P_Scen1,Conflict_risk,Conflict_risk_Scen1,Bird_Threat_P,Bird_Threat_P_Scen1,Bird_SeedC2,Bird_SeedC2_Scen1,Mam_SeedC2,Mam_SeedC2_Scen1,Bird_Carni_P,Bird_Carni_P_Scen1,Mam_CarniP,Mam_CarniP_Scen1)~Biome,mean,na.rm=T,data=trades_c)
dfin_ind$Biome<-"Cropland"
dfin_sma$Biome<-"Cropland"
set.seed(123)
#subsample to randomly pick 50 plots to make datasets coparable to ecological plots 
dfin_ind<-dfin_ind[sample(nrow(dfin_ind), size=50),]
dfin_sma<-dfin_sma[sample(nrow(dfin_sma), size=50),]
tra_ag_ind<-aggregate(cbind(Bird_SRC3,Bird_SRC3_Scen1,Mam_SRC3,Mam_SRC3_Scen1,Mam_Threat_P,Mam_Threat_P_Scen1,Conflict_risk,Conflict_risk_Scen1,Bird_Threat_P,Bird_Threat_P_Scen1,Bird_SeedC2,Bird_SeedC2_Scen1,Mam_SeedC2,Mam_SeedC2_Scen1,Bird_Carni_P,Bird_Carni_P_Scen1,Mam_CarniP,Mam_CarniP_Scen1)~Biome,mean,na.rm=T,data=dfin_ind)
tra_ag_sma<-aggregate(cbind(Bird_SRC3,Bird_SRC3_Scen1,Mam_SRC3,Mam_SRC3_Scen1,Mam_Threat_P,Mam_Threat_P_Scen1,Conflict_risk,Conflict_risk_Scen1,Bird_Threat_P,Bird_Threat_P_Scen1,Bird_SeedC2,Bird_SeedC2_Scen1,Mam_SeedC2,Mam_SeedC2_Scen1,Bird_Carni_P,Bird_Carni_P_Scen1,Mam_CarniP,Mam_CarniP_Scen1)~Biome,mean,na.rm=T,data=dfin_sma)

tra_ag$ID<-"Crop_plots"
tra_ag_ind$ID<-"Industry"
tra_ag_sma$ID<-"Smallholder"
df<-rbind(tra_ag,tra_ag_ind,tra_ag_sma)

colors <- c("Baseline" = "black", "Scenario" = "orange", "TChange" = "red")

fg<-ggplot(df) +
  geom_segment( aes(x=ID, xend=ID, y=Bird_SRC3, yend=Bird_SRC3_Scen1,color="TChange"),size=1) +
  geom_point(alpha=1, aes(x=ID, y=Bird_SRC3, col="Baseline"), size=6 ) +
  geom_point(alpha=0.5, aes(x=ID, y=Bird_SRC3_Scen1, col="Scenario"), size=5 ) +
   theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold"),
    #plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=24),
    axis.title.y=element_text(size=20),
    axis.text.y=element_text(size=22),
    axis.text.x=element_text(size=25),
  ) +
  xlab("") +
  ylab("Probability of high number of species")+
  ggtitle("(A) High number of bird species")+
  theme(legend.title = element_blank(),legend.position="none") 
fg
test<-fg+scale_colour_manual(values=c("black", "orange","red"), name="Before/After Restoration",labels=c("Baseline", "Scenario", "Change"))
test<-test+ theme(legend.title = element_blank(),legend.text = element_text (size = 28),legend.position=c(0.4,0.72)) 
test<-test+guides(color = guide_legend(override.aes = list(linetype=c(rep("blank",2),"solid"),
                                                           shape = c(19,19,NA))))
test
nam.pb<-paste("Fig_S8_A_Lollipop_BirdsSC3_Scen4_CropGEE","tiff",sep=".")
ggsave(test,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=9,height=4)

fg<-ggplot(df) +
  geom_segment( aes(x=ID, xend=ID, y=Conflict_risk, yend=Conflict_risk_Scen1,color="red")) +
  geom_point(alpha=1, aes(x=ID, y=Conflict_risk), color="black", size=6 ) +
  geom_point(alpha=0.5, aes(x=ID, y=Conflict_risk_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold"),
    #plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=24),
    axis.title.y=element_text(size=20),
    axis.text.y=element_text(size=22),
    axis.text.x=element_text(size=25),
  ) +
  xlab("") +
  ylab("Probability of crop raiding incident")+
  ggtitle("Crop - Elephant conflict risk")+
  theme(legend.title = element_blank(),legend.position="none") 
fg
nam.pb<-paste("Fig_S8_I_Lollipop_Conflict_Scen4_CropGEE","tiff",sep=".")
ggsave(fg,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=9,height=4)

fg<-ggplot(df) +
  geom_segment( aes(x=ID, xend=ID, y=Bird_Threat_P, yend=Bird_Threat_P_Scen1,color="red")) +
  geom_point(alpha=1, aes(x=ID, y=Bird_Threat_P), color="black", size=6 ) +
  geom_point(alpha=0.5, aes(x=ID, y=Bird_Threat_P_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold"),
    #plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=24),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=22),
    axis.text.x=element_text(size=25),
  ) +
  xlab("") +
  ylab("Probability of presence")+
  ggtitle("(C) Threatened birds")+
  theme(legend.title = element_blank(),legend.position="none") 
fg
nam.pb<-paste("Fig_S8_C_Lollipop_ThreatBirds_Scen4_CropGEE","tiff",sep=".")
ggsave(fg,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=9,height=4)

fg<-ggplot(df) +
  geom_segment( aes(x=ID, xend=ID, y=Mam_SRC3, yend=Mam_SRC3_Scen1,color="red")) +
  geom_point(alpha=1, aes(x=ID, y=Mam_SRC3), color="black", size=6 ) +
  geom_point(alpha=0.5, aes(x=ID, y=Mam_SRC3_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold"),
    #plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=24),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=22),
    axis.text.x=element_text(size=25),
  ) +
  xlab("") +
  ylab("Probability of high number of species")+
  ggtitle("(B) High number of mammal species")+
  theme(legend.title = element_blank(),legend.position="none") 
fg
nam.pb<-paste("Fig_S8_B_Lollipop_MamsSC3_Scen4_CropGEE","tiff",sep=".")
ggsave(fg,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=9,height=4)

fg<-ggplot(df) +
  geom_segment( aes(x=ID, xend=ID, y=Mam_Threat_P, yend=Mam_Threat_P_Scen1,color="red")) +
  geom_point(alpha=1, aes(x=ID, y=Mam_Threat_P), color="black", size=6 ) +
  geom_point(alpha=0.5, aes(x=ID, y=Mam_Threat_P_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold"),
    #plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=24),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=22),
    axis.text.x=element_text(size=25),
  ) +
  xlab("") +
  ylab("Probability of presence")+
  ggtitle("(D) Threatened mammals")+
  theme(legend.title = element_blank(),legend.position="none") 
fg
nam.pb<-paste("Fig_S8_D_Lollipop_ThreatMams_Scen4_CropGEE","tiff",sep=".")
ggsave(fg,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=9,height=4)

fg<-ggplot(df) +
  geom_segment( aes(x=ID, xend=ID, y=Mam_Threat_P, yend=Mam_Threat_P_Scen1,color="red")) +
  geom_point(alpha=1, aes(x=ID, y=Mam_Threat_P), color="black", size=6 ) +
  geom_point(alpha=0.5, aes(x=ID, y=Mam_Threat_P_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold"),
    #plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=24),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=22),
    axis.text.x=element_text(size=25),
  ) +
  xlab("") +
  ylab("Probability of presence")+
  ggtitle("Threatened mammals")+
  theme(legend.title = element_blank(),legend.position="none") 
fg
nam.pb<-paste("Fig_4_D_Lollipop_ThreatMams_Scen4_CropGEE","tiff",sep=".")
ggsave(fg,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=9,height=4)

fg<-ggplot(df) +
  geom_segment( aes(x=ID, xend=ID, y=Bird_Carni_P, yend=Bird_Carni_P_Scen1,color="red")) +
  geom_point(alpha=1, aes(x=ID, y=Bird_Carni_P), color="black", size=6 ) +
  geom_point(alpha=0.5, aes(x=ID, y=Bird_Carni_P_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold"),
    #plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=24),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=22),
    axis.text.x=element_text(size=25),
  ) +
  xlab("") +
  ylab("Probability of presence")+
  ggtitle("(G) carnivorous birds")+
  theme(legend.title = element_blank(),legend.position="none") 
fg
nam.pb<-paste("Fig_S8_G_Lollipop_CarnivBirds_Scen4_CropGEE","tiff",sep=".")
ggsave(fg,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=9,height=4)

fg<-ggplot(df) +
  geom_segment( aes(x=ID, xend=ID, y=Mam_CarniP, yend=Mam_CarniP_Scen1,color="red")) +
  geom_point(alpha=1, aes(x=ID, y=Mam_CarniP), color="black", size=6 ) +
  geom_point(alpha=0.5, aes(x=ID, y=Mam_CarniP_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold"),
    #plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=24),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=22),
    axis.text.x=element_text(size=25),
  ) +
  xlab("") +
  ylab("Probability of presence")+
  ggtitle("(H) carnivorous mammals")+
  theme(legend.title = element_blank(),legend.position="none") 
fg
nam.pb<-paste("Fig_S8_H_Lollipop_CarnivMams_Scen4_CropGEE","tiff",sep=".")
ggsave(fg,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=9,height=4)




fgmhs<-ggplot(df) +
  geom_segment( aes(x=ID, xend=ID, y=Mam_SeedC2, yend=Mam_SeedC2_Scen1,color="red")) +
  geom_point(alpha=1, aes(x=ID, y=Mam_SeedC2), color="black", size=6 ) +
  geom_point(alpha=0.5, aes(x=ID, y=Mam_SeedC2_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold"),
    #plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=24),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=22),
    axis.text.x=element_text(size=25),
  ) +
  xlab("") +
  ylab("Probability of high number")+
  ggtitle("(F) Plant & seed eating mammals")+
  theme(legend.title = element_blank(),legend.position="none") 
fgmhs
nam.pb<-paste("Fig_S8_F_Lollipop_MamsPlantSeed_Scen4_CropGEE","tiff",sep=".")
ggsave(fgmhs,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=9,height=4)

fgbhs<-ggplot(df) +
  geom_segment( aes(x=ID, xend=ID, y=Bird_SeedC2, yend=Bird_SeedC2_Scen1,color="red")) +
  geom_point(alpha=1, aes(x=ID, y=Bird_SeedC2), color="black", size=6 ) +
  geom_point(alpha=0.5, aes(x=ID, y=Bird_SeedC2_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold"),
    #plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=24),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=22),
    axis.text.x=element_text(size=25),
  ) +
  xlab("") +
  ylab("Probability of high number")+
  ggtitle("(E) Plant & seed eating birds")+
  theme(legend.title = element_blank(),legend.position="none") 
fgbhs
nam.pb<-paste("Fig_S8_E_Lollipop_BirdsPlantSeed_Scen4_CropGEE","tiff",sep=".")
ggsave(fgbhs,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=9,height=4)


# ####(5.7) Fig 4 creation ------------------------------------------------

tra_agb<-aggregate(cbind(Bird_SRC3,Bird_SRC3_Scen1,Mam_SRC3,Mam_SRC3_Scen1,Mam_Threat_P,Mam_Threat_P_Scen1,Conflict_risk,Conflict_risk_Scen1,Bird_Threat_P,Bird_Threat_P_Scen1,Bird_SeedC2,Bird_SeedC2_Scen1,Mam_SeedC2,Mam_SeedC2_Scen1,Bird_Carni_P,Bird_Carni_P_Scen1,Mam_CarniP,Mam_CarniP_Scen1)~Biome,mean,na.rm=T,data=trades)

temp<-round(tra_agb$Bird_SRC3_Scen1-tra_agb$Bird_SRC3,2)
length(which(temp<0))
length(which(temp>0))
mean(temp[which(temp<0)])

data.frame(tra_agb$Biome,scen1=round(tra_agb$Mam_Threat_P_Scen1-tra_agb$Mam_Threat_P,2))
data.frame(tra_agb$Biome,scen1=round(tra_agb$Mam_SRC3_Scen1-tra_agb$Mam_SRC3,2))
data.frame(tra_agb$Biome,scen1=round(tra_agb$Bird_Threat_P_Scen1-tra_agb$Bird_Threat_P,2))
data.frame(tra_agb$Biome,scen1=round(tra_agb$Bird_SRC3_Scen1-tra_agb$Bird_SRC3,2))

data.frame(tra_agb$Biome,scen1=round(tra_agb$Mam_SeedC2_Scen1-tra_agb$Mam_SeedC2,2))


Fig_5_na<-ggplot(tra_agb) +
  geom_segment( aes(x=Biome, xend=Biome, y=Mam_SRC3, yend=Mam_SRC3_Scen1,color="red")) +
  geom_point(alpha=1, aes(x=Biome, y=Mam_SRC3), color="darkgrey", size=6 ) +
  geom_point(alpha=0.5, aes(x=Biome, y=Mam_SRC3_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold"),
    #plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=24),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=22),
    axis.text.x=element_text(size=25),
  ) +
  xlab("") +
  ylab("Probability of high number of species")+
  ggtitle("(B) High number of mammal species")+
  theme(legend.title = element_blank(),legend.position="none") 
Fig_5_na
nam.pb<-paste("Fig_4_Lollipop_MamsSC3_Scen4_Biomes","tiff",sep=".")
ggsave(Fig_5_na,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=8,height=4)

Fig_5_nb<-ggplot(tra_agb) +
  geom_segment( aes(x=Biome, xend=Biome, y=Mam_Threat_P, yend=Mam_Threat_P_Scen1,color="red")) +
  geom_point(alpha=1, aes(x=Biome, y=Mam_Threat_P), color="darkgrey", size=6 ) +
  geom_point(alpha=0.5, aes(x=Biome, y=Mam_Threat_P_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold"),
    #plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=24),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=22),
    axis.text.x=element_text(size=25),
  ) +
  xlab("") +
  ylab("Probability of presence")+
  ggtitle("(D) Presence of threatened mammals")+
  theme(legend.title = element_blank(),legend.position="none") 
Fig_5_nb
nam.pb<-paste("Fig_4_Lollipop_ThreatMams_Scen4_Biomes","tiff",sep=".")
ggsave(Fig_5_nb,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=8,height=4)

colors <- c("Baseline" = "darkgrey", "Scenario" = "orange", "TChange" = "red")

Fig_5_nc<-ggplot(tra_agb) +
  geom_segment( aes(x=Biome, xend=Biome, y=Bird_SRC3, yend=Bird_SRC3_Scen1,color="TChange")) +
  geom_point(alpha=1, aes(x=Biome, y=Bird_SRC3, col="Baseline"), size=6 ) +
  geom_point(alpha=0.5, aes(x=Biome, y=Bird_SRC3_Scen1, col="Scenario"), size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold"),
    #plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=24),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=22),
    axis.text.x=element_text(size=25),
  ) +
  labs(x = "",
       y = "Probability of high number of species",
       color = "Legend") +
  scale_color_manual(values = colors)+
  ggtitle("(A) High number of bird species")
Fig_5_nc 
test<-Fig_5_nc+scale_colour_manual(values=c("darkgrey", "orange","red"), name="Before/After Restoration",labels=c("Baseline", "Scenario", "Change"))
test<-test+ theme(legend.title = element_blank(),legend.text = element_text (size = 28),legend.position=c(0.4,0.6)) 
test<-test+guides(color = guide_legend(override.aes = list(linetype=c(rep("blank",2),"solid"),
                                                    shape = c(19,19,NA))))
test
#Fig_5_nc
nam.pb<-paste("Fig_4_Lollipop_BirdsSC3_Scen4_Biomes","tiff",sep=".")
ggsave(test,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=8,height=4)

Fig_5_nd<-ggplot(tra_agb) +
  geom_segment( aes(x=Biome, xend=Biome, y=Bird_Threat_P, yend=Bird_Threat_P_Scen1,color="red")) +
  geom_point(alpha=1, aes(x=Biome, y=Bird_Threat_P), color="darkgrey", size=6 ) +
  geom_point(alpha=0.5, aes(x=Biome, y=Bird_Threat_P_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold"),
    #plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=24),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=22),
    axis.text.x=element_text(size=25),
  ) +
  xlab("") +
  ylab("Probability of presence")+
  ggtitle("(C) Presence of threatened birds")+
  theme(legend.title = element_blank(),legend.position="none") 
Fig_5_nd
nam.pb<-paste("Fig_4_Lollipop_ThreatBird_Scen4_Biomes","tiff",sep=".")
ggsave(Fig_5_nd,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=8,height=4)


Fig_5_nde<-ggplot(tra_agb) +
  geom_segment( aes(x=Biome, xend=Biome, y=Mam_SeedC2, yend=Mam_SeedC2_Scen1,color="red")) +
  geom_point(alpha=1, aes(x=Biome, y=Mam_SeedC2), color="darkgrey", size=6 ) +
  geom_point(alpha=0.5, aes(x=Biome, y=Mam_SeedC2_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold"),
    #plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=24),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=22),
    axis.text.x=element_text(size=25),
  ) +
  xlab("") +
  ylab("Probability of high number of species")+
  ggtitle("(F) Plant & seed eating mammals")+
  theme(legend.title = element_blank(),legend.position="none") 
Fig_5_nde
nam.pb<-paste("Fig_4_Lollipop_MamPlantSeedC2_Scen4_Biomes","tiff",sep=".")
ggsave(Fig_5_nde,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=8,height=4)

Fig_5_ndf<-ggplot(tra_agb) +
  geom_segment( aes(x=Biome, xend=Biome, y=Bird_SeedC2, yend=Bird_SeedC2_Scen1,color="red")) +
  geom_point(alpha=1, aes(x=Biome, y=Bird_SeedC2), color="darkgrey", size=6 ) +
  geom_point(alpha=0.5, aes(x=Biome, y=Bird_SeedC2_Scen1), color="orange", size=5 ) +
  theme_light() +
  coord_flip() +
  theme(
    plot.title = element_text(size=25, face="bold"),
    #plot.title = element_text(size=25, face="bold.italic"),
    axis.ticks.y = element_blank(),
    axis.title.x=element_text(size=24),
    axis.title.y=element_text(size=22),
    axis.text.y=element_text(size=22),
    axis.text.x=element_text(size=25),
  ) +
  xlab("") +
  ylab("Probability of high number of species")+
  ggtitle("(E) Plant & seed eating birds")+
  theme(legend.title = element_blank(),legend.position="none") 
Fig_5_ndf
nam.pb<-paste("Fig_4_Lollipop_BirdPlantSeedC2_Scen4_Biomes","tiff",sep=".")
ggsave(Fig_5_ndf,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=8,height=4)


# ###### (5.8) Wellbeing data : Fig S8 and Fig 6  -------------------------


dev.off()

#explorative visualisation
fig_crop_vil<-ggplot(soci,aes(pre.start.village,wci_max_01,fill=pre.start.village))+
  geom_boxplot(position=position_dodge(1))+
  facet_wrap(~factor(elephant_damage))+
  theme( axis.text.x=element_text(size=15,angle=90))
nam.pb<-paste("Fig_Boxplot_Wellbe_Village_Cropdamage","tiff",sep=".")
ggsave(fig_crop_vil,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=8,height=7)
fig_crop_vil

soci$pid <- reorder(soci$pid, soci$yield_staple)
soci$plot<-ifelse(is.na(soci$pre.start.gps.group.farmer.plot.id),"Plot",soci$pre.start.gps.group.farmer.plot.id)

keep.var<-c("soc_gender","crop_damage","elephant_damage","pre.start.village",
            "wci_max_01","dietdiv","ForestPerc250","yield_staple",
            "material_dim","security_dim","health_dim","social_dim",
            "freedom_dim","pcp_percept_nat_overall","disforestlandsat","plot"
            )


soci1<-soci[,keep.var]
soci1<-na.omit(soci1)#dont take the plot id column into accont for this step
#soci1<-na.omit(soci1)#remoed NA from datframe soci
names(soci1)
head(soci1)
soci1$sex_cropdamage<-paste(soci1$soc_gender,soci1$crop_damage,sep="_")
soci1$sex_elephantdamage<-paste(soci1$soc_gender,soci1$elephant_damage,sep="_")

length(rownames(soci1))


#this one looks cool
soci1$sex_cropdamage<-ifelse(soci1$sex_cropdamage=="0_0","Male, less crop damage",soci1$sex_cropdamage)
soci1$sex_cropdamage<-ifelse(soci1$sex_cropdamage=="0_1","Male, more crop damage",soci1$sex_cropdamage)
soci1$sex_cropdamage<-ifelse(soci1$sex_cropdamage=="1_0","Female, less crop damage",soci1$sex_cropdamage)
soci1$sex_cropdamage<-ifelse(soci1$sex_cropdamage=="1_1","Female, more crop damage",soci1$sex_cropdamage)

soci1$sex_elephantdamage<-ifelse(soci1$sex_elephantdamage=="0_0","Male, no elephant damage",soci1$sex_elephantdamage)
soci1$sex_elephantdamage<-ifelse(soci1$sex_elephantdamage=="0_1","Male, elephant damage",soci1$sex_elephantdamage)
soci1$sex_elephantdamage<-ifelse(soci1$sex_elephantdamage=="1_0","Female, no elephant damage",soci1$sex_elephantdamage)
soci1$sex_elephantdamage<-ifelse(soci1$sex_elephantdamage=="1_1","Female, elephant damage",soci1$sex_elephantdamage)

#diet diversity is  important component of wellbeing metric
ggplot(soci1,aes(dietdiv,wci_max_01,col=pre.start.village))+geom_point()+geom_smooth()
#diet dversity shows now clear pattern with amout of froest in surrounding
ggplot(soci1,aes(ForestPerc250,dietdiv,col=pre.start.village))+geom_point()+geom_smooth()

#
soci1$sex<-ifelse(soci1$soc_gender=="1","Female","Male")

ggplot(soci1,aes(yield_staple,wci_max_01,col=factor(sex)))+geom_point()+geom_smooth()
ggplot(soci1,aes(yield_staple,material_dim,col=factor(sex)))+geom_point()+geom_smooth()
ggplot(soci1,aes(yield_staple,security_dim,col=factor(sex)))+geom_point()+geom_smooth()
ggplot(soci1,aes(yield_staple,health_dim,col=factor(sex)))+geom_point()+geom_smooth()
ggplot(soci1,aes(yield_staple,social_dim,col=factor(sex)))+geom_point()+geom_smooth()
ggplot(soci1,aes(yield_staple,freedom_dim,col=factor(sex)))+geom_point()+geom_smooth()

ggplot(soci1,aes(yield_staple,health_dim))+geom_point()+geom_smooth()
names(trades)

soci1$yield_sugarcane<-trades$yield_sugarcane[match(soci1$plot,trades$plot)]
soci1$yield_okra<-trades$yield_okra[match(soci1$plot,trades$plot)]

ggplot(soci1,aes(yield_okra,wci_max_01,col=factor(sex)))+geom_point()+geom_smooth()

ggplot(soci1,aes(factor(pcp_percept_nat_overall),ForestPerc250))+geom_boxplot()
ggplot(soci1,aes(factor(pcp_percept_nat_overall),disforestlandsat))+geom_boxplot()
ggplot(soci1,aes(factor(pcp_percept_nat_overall),wci_max_01,col=factor(sex_cropdamage)))+
  geom_boxplot()
ggplot(soci1,aes(factor(pcp_percept_nat_overall),wci_max_01,col=factor(soc_gender)))+
  geom_boxplot()
ggplot(soci1,aes(factor(pcp_percept_nat_overall),wci_max_01,col=factor(sex_cropdamage)))+
  geom_boxplot()+facet_wrap(~sex_cropdamage)

colsexcrop<-c(cols3[12],cols3[6],cols3[1],cols3[5])
fig_8<-ggplot(soci1,aes(pcp_percept_nat_overall,wci_max_01,col=factor(sex_cropdamage)))+
  geom_point()+facet_wrap(~sex_cropdamage)+geom_smooth()+
  theme_bw()+theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+
  guides(color=guide_legend(override.aes=list(fill=NA)),
         fill=guide_legend(title="Sex & crop damage"))+
  scale_color_manual(values=colsexcrop)+
  theme(axis.title.x=element_text(vjust=-0.35,size=25),axis.title.y=element_text(vjust= +0.9,size=20),
        axis.text.x=element_text(size=25,angle=-90),axis.text.y=element_text(size=20),
        legend.title = element_text(size=25, face="bold"),
        legend.text = element_text(size = 25),
        legend.position="None",
        strip.text = element_text(size = 15))+
  ylab("Wellbeing")+xlab("Perceptions of Nature [1-5]")
fig_8
# theme(legend.title = element_blank(),legend.position=c(0.3,0.3)) 
nam.pb<-paste("Fig_Wellb_NaturePercept_Crop damage","tiff",sep=".")
ggsave(fig_8,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=10,height=8)

fig_8<-ggplot(soci1,aes(wci_max_01,pcp_percept_nat_overall,col=factor(sex_cropdamage)))+
  geom_point()+facet_wrap(~sex_cropdamage)+geom_smooth()+
  theme_bw()+theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+
  guides(color=guide_legend(override.aes=list(fill=NA)),
         fill=guide_legend(title="Sex & crop damage"))+
  scale_color_manual(values=colsexcrop)+
  theme(axis.title.x=element_text(vjust=-0.35,size=25),axis.title.y=element_text(vjust= +0.9,size=20),
        axis.text.x=element_text(size=25,angle=-90),axis.text.y=element_text(size=20),
        legend.title = element_text(size=25, face="bold"),
        legend.text = element_text(size = 25),
        legend.position="None",
        strip.text = element_text(size = 15))+
  xlab("Wellbeing")+ylab("Perceptions of Nature [1-5]")
fig_8
# theme(legend.title = element_blank(),legend.position=c(0.3,0.3)) 
nam.pb<-paste("Fig_NaturePercept_Wellb_Crop damage","tiff",sep=".")
ggsave(fig_8,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=10,height=8)

length(soci1$pcp_percept_nat_overall)
fig_8<-ggplot(soci1,aes(wci_max_01,pcp_percept_nat_overall,col=factor(sex_elephantdamage)))+
  geom_point()+facet_wrap(~sex_elephantdamage)+geom_smooth()+
  theme_bw()+theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+
  guides(color=guide_legend(override.aes=list(fill=NA)),
         fill=guide_legend(title="Sex & crop damage"))+
  scale_color_manual(values=colsexcrop)+
  theme(axis.title.x=element_text(vjust=-0.35,size=25),axis.title.y=element_text(vjust= +0.9,size=20),
        axis.text.x=element_text(size=25,angle=-90),axis.text.y=element_text(size=20),
        legend.title = element_text(size=25, face="bold"),
        legend.text = element_text(size = 25),
        legend.position="None",
        strip.text = element_text(size = 15))+
  xlab("Wellbeing")+ylab("Perceptions of Nature [1-5]")
fig_8
# theme(legend.title = element_blank(),legend.position=c(0.3,0.3)) 
nam.pb<-paste("Fig_6_NaturePercept_Wellb_Elephantdamage","tiff",sep=".")
ggsave(fig_8,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=10,height=8)


names(soci1)
soci1$pre.start.village


#merge
keep.var<-c("soc_gender","wci_max_01")
taq1<-melt(soci[,keep.var],id.var="soc_gender")
head(taq1)
#male and female colour
colsex<-c(cols3[6],cols3[5])

#does well-being differ between males and females?
taq1$soc_gender<-ifelse(taq1$soc_gender==1,"Female","Male")
x<-as.factor(taq1$soc_gender)
y<-taq1$value
summary(aov(y~x))
TukeyHSD(aov(y~x))

soci$sex<-soci$soc_gender
soci$sex<-ifelse(soci$sex==1,"Female","Male")
soci$crop_damage_text<-soci$crop_damage
soci$crop_damage_text<-ifelse(soci$crop_damage_text==1,"more damage","less damage")
soci$sex_cropdamage<-paste(soci$sex,soci$crop_damage_text,sep=", ")

colsexcrop<-c(cols3[12],cols3[6],cols3[1],cols3[5])
keep.var<-c("sex_cropdamage","wci_max_01")
taq1a<-melt(soci1[,keep.var],id.var="sex_cropdamage")
head(taq1a)
summary(aov(taq1a$value~taq1a$sex_cropdamage))
TukeyHSD(aov(taq1a$value~taq1a$sex_cropdamage))

well_fig1a<-ggplot(taq1a,aes(x=value,fill=factor(sex_cropdamage))) + 
  geom_density(alpha=0.7)+ 
  theme_bw()+theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+
  guides(color=guide_legend(override.aes=list(fill=NA)),
         fill=guide_legend(title="Sex"))+
  scale_fill_manual(values=colsexcrop)+
  theme(axis.title.x=element_text(vjust=-0.35,size=25),axis.title.y=element_text(vjust= +0.9,size=25),
        axis.text.x=element_text(size=25,angle=-90),axis.text.y=element_text(size=20),
        legend.title = element_text(size=20, face="bold"),
        legend.text = element_text(size = 16))+
  xlab("Wellbeing Index") +
  theme(legend.title = element_blank(),legend.position=c(0.8,0.8)) 
well_fig1a
nam.pb<-paste("Fig_S9_a_WellbeingCropDamage_Sex","tiff",sep=".")
ggsave(well_fig1a,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=10,height=8)

keep.var<-c("sex_elephantdamage","wci_max_01")
taq1a<-melt(soci1[,keep.var],id.var="sex_elephantdamage")
head(taq1a)
well_fig1a<-ggplot(taq1a,aes(x=value,fill=factor(sex_elephantdamage))) + 
  geom_density(alpha=0.7)+ 
  theme_bw()+theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+
  guides(color=guide_legend(override.aes=list(fill=NA)),
         fill=guide_legend(title="Sex"))+
  scale_fill_manual(values=colsexcrop)+
  theme(axis.title.x=element_text(vjust=-0.35,size=25),axis.title.y=element_text(vjust= +0.9,size=25),
        axis.text.x=element_text(size=25,angle=-90),axis.text.y=element_text(size=20),
        legend.title = element_text(size=20, face="bold"),
        legend.text = element_text(size = 16))+
  xlab("Wellbeing Index") +
  theme(legend.title = element_blank(),legend.position=c(0.8,0.8)) 
well_fig1a
nam.pb<-paste("Fig_S9_b_WellbeingElephantDamage_Sex","tiff",sep=".")
ggsave(well_fig1a,filename=paste(dirGG,nam.pb,sep="/"),dpi=300,width=10,height=8)

summary(aov(taq1a$value~taq1a$sex_elephantdamage))
TukeyHSD(aov(taq1a$value~taq1a$sex_elephantdamage))

# ####(5.9) Wellbeing- radarchart part of S9-----------------------------------------


#install.packages("rstatix")
#library(rstatix)
#anova_test(y~x)
#females and males have similar well-b

names(soci)
length(rownames(soci)) #498 points
length(rownames(soci1)) #461 points
keep.var<-c("material_dim","health_dim","social_dim","security_dim","freedom_dim","wci_max_01")
soci_ag<-aggregate(cbind(material_dim,health_dim,social_dim,security_dim,freedom_dim,wci_max_01,dietdiv,yield_staple)~soc_gender,mean,na.rm=T,data=soci)
soci_ag_min<-aggregate(cbind(material_dim,health_dim,social_dim,security_dim,freedom_dim,wci_max_01,dietdiv,yield_staple)~soc_gender,min,na.rm=T,data=soci)
soci_ag_max<-aggregate(cbind(material_dim,health_dim,social_dim,security_dim,freedom_dim,wci_max_01,dietdiv,yield_staple)~soc_gender,max,na.rm=T,data=soci)

# # Define the variable ranges: maximum and minimum
max_min <- data.frame(
  material_dim = c(max(soci$material_dim,na.rm=T), 0), health_dim = c(max(soci$health_dim,na.rm=T), 0),
  social_dim = c(max(soci$social_dim,na.rm=T),0),
  security_dim = c(max(soci$social_dim,na.rm=T),0), freedom_dim = c(max(soci$freedom_dim,na.rm=T),0), 
  wci_max_01=c(max(soci$wci_max_01,na.rm=T),0),dietdiv = c(max(soci$dietdiv,na.rm=T),0),
  yield_staple=c(max(soci$yield_staple,na.rm=T),0)
)
rownames(max_min) <- c("Max", "Min")
rownames(soci_ag)<-c("male","female")

dfsoc <- rbind(max_min, soci_ag[,-1])
names(dfsoc)<-c("Material","Health","Social","Security","Freedom","Wellbeing","Diet","Yield")

#landscape configuration trade offs with well-being (or not)
names(soci)
keep.var<-c("material_dim","health_dim","social_dim","security_dim","freedom_dim","wci_max_01","pcp_percept_nat_overall","nature_access")
soci_ag1<-aggregate(cbind(material_dim,health_dim,social_dim,security_dim,freedom_dim,pcp_percept_nat_overall,nature_access,ForestPerc250,disforestlandsat)~soc_gender,mean,na.rm=T,data=soci)
soci_ag1_max<-aggregate(cbind(material_dim,health_dim,social_dim,security_dim,freedom_dim,pcp_percept_nat_overall,nature_access,ForestPerc250,disforestlandsat)~soc_gender,max,na.rm=T,data=soci)
soci_ag1_min<-aggregate(cbind(material_dim,health_dim,social_dim,security_dim,freedom_dim,pcp_percept_nat_overall,nature_access,ForestPerc250,disforestlandsat)~soc_gender,min,na.rm=T,data=soci)

max<-apply(X=soci_ag1_max, MARGIN=2, FUN=max)
min<-apply(X=soci_ag1_min, MARGIN=2, FUN=min)
dfsoc1 <- rbind(max, min,soci_ag1)
rownames(dfsoc1)<-c("Max","Min","Male","Female")
dfsoc1<-dfsoc1[,-1]
#radarchart(dfsoc1[,c(6:9)],col="green")

names(dfsoc1)<-c("Material","Health","Social","Security","Freedom","Nature perception","Nature Access","Forest Perc 250","Distance to Forest")
# a<-dfnew[c(1:3),]
# b<-dfnew[c(1,2,4),]
# c<-dfnew[c(1,2,5),]
# d<-dfnew[c(1,2,6),]
radarchart(dfsoc[,c(1:5)],col="green")
# Prepare color
# colors_border=c( rgb(0.2,0.5,0.5,0.9), rgb(0.8,0.2,0.5,0.9)  )
# colors_in=c( rgb(0.2,0.5,0.5,0.4), rgb(0.8,0.2,0.5,0.4)  )
colors_in<-rev(colsex)
colors_border=rev(colsex)
#rev(c(cols1[1],cols1[2]))

# Custom the radarChart !
radarchart(dfsoc1[,c(1:5)], axistype=1, 
           #custom polygon
           pcol=colors_border , pfcol=scales::alpha(colors_in,c(0.6,0.5)), 
           plwd=2, plty=1 , 
           #custom the grid
           cglcol="grey", cglty=1, axislabcol="grey", cglwd=1.1,
           caxislabels=seq(0,1,5), 
           #custom labels
           vlcex=0.8 ,
           seg=2
           
)

legend(x=1, y=1.5, legend = c("Male", "Female"), bty = "n", pch=20 , col=colors_border , text.col = "black", cex=0.9, pt.cex=1.6)

###include crop damage
keep.var<-c("material_dim","health_dim","social_dim","security_dim","freedom_dim","wci_max_01","pcp_percept_nat_overall","nature_access")
soci_ag2<-aggregate(cbind(material_dim,health_dim,social_dim,security_dim,freedom_dim,pcp_percept_nat_overall,nature_access,ForestPerc250,disforestlandsat)~soc_gender+crop_damage,mean,na.rm=T,data=soci)
#soci_ag1_max<-aggregate(cbind(material_dim,health_dim,social_dim,security_dim,freedom_dim,pcp_percept_nat_overall,nature_access,ForestPerc250,disforestlandsat)~soc_gender+crop_damage,FUN=max,data=soci)
#soci_ag1_min<-aggregate(cbind(material_dim,health_dim,social_dim,security_dim,freedom_dim,pcp_percept_nat_overall,nature_access,ForestPerc250,disforestlandsat)~soc_gender+crop_damage,FUN=min,data=soci)
#max<-apply(X=soci_ag1_max, MARGIN=2, FUN=max)
#min<-apply(X=soci_ag1_min, MARGIN=2, FUN=min)
soci_ag2$soc_gender<-ifelse(soci_ag2$soc_gender==1,"Female","Male")
soci_ag2$crop_damage<-ifelse(soci_ag2$crop_damage==1,"> 25 % damage","< 25 % damage")
dfsoc2 <- rbind(max, min,soci_ag2)
rownames(dfsoc2)<-c("Max","Min","Male, few damage","Female, few damage","Male, big damage","Female, big damage")
dfsoc2<-dfsoc2[,-c(1,2)]
#radarchart(dfsoc1[,c(6:9)],col="green")

names(dfsoc2)<-c("Material","Health","Social","Security","Freedom","Nature perception","Nature Access","Forest Perc 250","Distance to Forest")

colors_in<-rev(colsex)
colors_border=rev(colsex)
#rev(c(cols1[1],cols1[2]))

# Custom the radarChart !
radarchart(dfsoc2[c(1:4),c(1:5)], axistype=1, 
           #custom polygon
           pcol=colors_border , pfcol=scales::alpha(colors_in,c(0.6,0.5)), plwd=2, plty=1 , 
           #custom the grid
           cglcol="grey", cglty=1, axislabcol="grey", cglwd=1.1,
           caxislabels=seq(0,1,5), 
           #custom labels
           vlcex=0.8 ,
           seg=2
)

legend(x=1, y=1.5, legend = c("Male, < 25 % damage", "Female, < 25 % damage"), bty = "n", pch=20 , col=colors_border , text.col = "black", cex=0.9, pt.cex=1.6)

radarchart(dfsoc2[c(1:2,5,6),c(1:5)], axistype=1, 
           #custom polygon
           pcol=colors_border , pfcol=scales::alpha(colors_in,c(0.6,0.5)), plwd=2, plty=1 , 
           #custom the grid
           cglcol="grey", cglty=1, axislabcol="grey", cglwd=1.1,
           caxislabels=seq(0,1,5), 
           #custom labels
           vlcex=0.8 ,
           seg=2
)

legend(x=1, y=1.5, legend = c("Male, > 25 % damage", "Female, > 25 % damage"), bty = "n", pch=20 , col=colors_border , text.col = "black", cex=0.9, pt.cex=1.6)


# ####(5.10) Welbbeing models ---------------------------------------------

###some mixed effect modelling
#https://www.flutterbys.com.au/stats/tut/tut9.1.html
names(soci1)
length(rownames(soci1))
library(nlme)


#### create intercept-only base-line model for wellbeing as response
library(lme4)
m0.lm <- lmer(wci_max_01 ~ 1 | pre.start.village, soci1,REML=FALSE)
# compare the base-line and the more saturated model
data.hier.lme <- lmer(wci_max_01 ~ elephant_damage + (1 | pre.start.village), soci1,REML=FALSE)
plot(data.hier.lme)
summary(data.hier.lme)
anova(data.hier.lme, m0.lm)

data.hier.lme1 <- lmer(wci_max_01 ~ soc_gender + (1 | pre.start.village), soci1,REML=FALSE)
plot(data.hier.lme1)
summary(data.hier.lme1)
anova(data.hier.lme1, m0.lm, test = "F")

data.hier.lme2 <- lmer(wci_max_01 ~ soc_gender + crop_damage+ (1 | pre.start.village), soci1,REML=FALSE)
plot(data.hier.lme2)
summary(data.hier.lme2)
anova(data.hier.lme2, data.hier.lme1, test = "F")

data.hier.lme2a <- lmer(wci_max_01 ~ crop_damage+ (1 | pre.start.village), soci1,REML=FALSE)
plot(data.hier.lme2a)
summary(data.hier.lme2a)
anova(data.hier.lme2a, m0.lm, test = "F")

data.hier.lme3 <- lmer(wci_max_01 ~ soc_gender + elephant_damage+ (1 | pre.start.village), soci1,REML=FALSE)
plot(data.hier.lme3)
summary(data.hier.lme3)
anova(data.hier.lme3, data.hier.lme1, test = "F")

data.hier.lme3a <- lmer(wci_max_01 ~ elephant_damage+ (1 | pre.start.village), soci1,REML=FALSE)
plot(data.hier.lme3a)
summary(data.hier.lme3a)
anova(data.hier.lme3a, m0.lm, test = "F")



###ordinal regression models to test for effects on people perceptions of nature's values
#install.packages("VGAM")
library(VGAM)

#(1) null model: perceptions of nature's values
vglm0 <- vglm(pcp_percept_nat_overall ~ 1, family=propodds, data=soci1)

#model fit 1: wellbeing as predictor
(vglmFit1 <- vglm(pcp_percept_nat_overall ~ wci_max_01, family=propodds, data=soci1, model=TRUE))
summary(vglmFit1)
anova(vglmFit1, vglm0, type="I")

#model fit 2: wellbeing and self reproted crop damage
(vglmFit <- vglm(pcp_percept_nat_overall ~ wci_max_01 + as.factor(crop_damage), family=propodds, data=soci1, model=TRUE))
summary(vglmFit)
anova(vglmFit1, vglmFit, type="I") #crop damage adds nothing
AIC(vglmFit1)
AIC(vglmFit)
AIC(vglm0)

#model fit 3: wellbeing and gender
(vglmFit2a <- vglm(pcp_percept_nat_overall ~ wci_max_01 + as.factor(soc_gender), family=propodds, data=soci1, model=TRUE))
summary(vglmFit2a)
anova(vglmFit2a, vglmFit1, type="I") 
sumOrd   <- summary(vglmFit2a)
(coefOrd <- coef(sumOrd))

##testing and comparing things
(vglmFit2b <- vglm(pcp_percept_nat_overall ~ wci_max_01 +as.factor(soc_gender)+ as.factor(soc_gender):as.factor(crop_damage), family=propodds, data=soci1, model=TRUE))
summary(vglmFit2b)

(vglmFit2 <- vglm(pcp_percept_nat_overall ~ wci_max_01 +as.factor(soc_gender)+ as.factor(crop_damage), family=propodds, data=soci1, model=TRUE))
summary(vglmFit2)
anova(vglmFit2, vglmFit2a, type="I") 
anova(vglmFit2a, vglmFit2b, type="I") 

#model 4: wellbeing and gender and village name
(vglmFit2c <- vglm(pcp_percept_nat_overall ~ wci_max_01 +as.factor(soc_gender)+ as.factor(pre.start.village), family=propodds, data=soci1, model=TRUE))
summary(vglmFit2c)
anova(vglmFit2a, vglmFit2c, type="I") 
anova(vglmFit1, vglmFit2c, type="I") 
AIC(vglmFit2c)

#compare against
(vglmFit2c1 <- vglm(pcp_percept_nat_overall ~ wci_max_01 + as.factor(pre.start.village), family=propodds, data=soci1, model=TRUE))
summary(vglmFit2c1)
anova(vglmFit1, vglmFit2c1, type="I") 
AIC(vglmFit2c1)
anova(vglmFit2c1, vglmFit2c, type="I") 


(vglmFit2d <- vglm(pcp_percept_nat_overall ~ wci_max_01 +as.factor(soc_gender)+ as.factor(pre.start.village)+as.factor(crop_damage), family=propodds, data=soci1, model=TRUE))
summary(vglmFit2d)
anova(vglmFit2c, vglmFit2d, type="I") 

(vglmFit2e <- vglm(pcp_percept_nat_overall ~ wci_max_01 +as.factor(soc_gender)+ as.factor(pre.start.village)+as.factor(crop_damage):as.factor(soc_gender), family=propodds, data=soci1, model=TRUE))
summary(vglmFit2e)
anova(vglmFit2c, vglmFit2e, type="I") 

#best fittig model
sumOrd   <- summary(vglmFit2c)
(coefOrd <- coef(sumOrd))



PhatCateg <- VGAM::predict(vglmFit2c, type="response")
head(PhatCateg)
categHat <- levels(factor(soci1$pcp_percept_nat_overall))[max.col(PhatCateg)]
head(categHat)
sumOrd   <- summary(vglmFit2c)
(coefOrd <- coef(sumOrd))
AIC(vglmFit2c)

(vglmFit3 <- vglm(pcp_percept_nat_overall ~ wci_max_01 + as.factor(crop_damage)*as.factor(soc_gender)+pre.start.village, family=propodds, data=soci1, model=TRUE))
summary(vglmFit3)
anova(vglmFit3, vglmFit2, type="I") #crop damage adds nothing
AIC(vglmFit3)

(vglmFit3a <- vglm(pcp_percept_nat_overall ~ wci_max_01 +pre.start.village, family=propodds, data=soci1, model=TRUE))
summary(vglmFit3a)
anova(vglmFit3a, vglmFit3, type="I") #crop damage adds nothing
AIC(vglmFit3a)


##try the same with and without adding elephant induced damage
vglm0 <- vglm(pcp_percept_nat_overall ~ 1, family=propodds, data=soci1)


(vglmFit1 <- vglm(pcp_percept_nat_overall ~ wci_max_01, family=propodds, data=soci1, model=TRUE))
summary(vglmFit1)
anova(vglmFit1, vglm0, type="I")

(vglmFit2 <- vglm(pcp_percept_nat_overall ~ wci_max_01+as.factor(elephant_damage), family=propodds, data=soci1, model=TRUE))
summary(vglmFit2)
anova(vglmFit2, vglmFit1, type="I") #signfciantly better
AIC(vglmFit2)

(vglmFit2a <- vglm(pcp_percept_nat_overall ~ wci_max_01+as.factor(soc_gender), family=propodds, data=soci1, model=TRUE))
summary(vglmFit2a)
anova(vglmFit2a, vglmFit1, type="I") #not sigfnicaintly better
AIC(vglmFit2a)

(vglmFit2b <- vglm(pcp_percept_nat_overall ~ wci_max_01+as.factor(elephant_damage)+as.factor(soc_gender), family=propodds, data=soci1, model=TRUE))
summary(vglmFit2b)
anova(vglmFit2b, vglmFit2, type="I") #adding signficaint value
AIC(vglmFit2b)

(vglmFit2c <- vglm(pcp_percept_nat_overall ~ wci_max_01+as.factor(elephant_damage)+as.factor(soc_gender)+pre.start.village, family=propodds, data=soci1, model=TRUE))
summary(vglmFit2c)
anova(vglmFit2c, vglmFit2b, type="I")
AIC(vglmFit2c)

#final model applicable to interpretation of findings
(vglmFit2d <- vglm(pcp_percept_nat_overall ~ wci_max_01+as.factor(soc_gender)+pre.start.village, family=propodds, data=soci1, model=TRUE))
summary(vglmFit2d) #summary stats for coefficients
anova(vglmFit2c, vglmFit2d, type="I")
AIC(vglmFit2d)




(vglmFit3 <- vglm(pcp_percept_nat_overall ~ wci_max_01+elephant_damage*soc_gender, family=propodds, data=soci1, model=TRUE))
summary(vglmFit3)
anova(vglmFit3, vglmFit2, type="I")
AIC(vglmFit3)

(vglmFit3a <- vglm(pcp_percept_nat_overall ~ wci_max_01+elephant_damage*soc_gender+pre.start.village, family=propodds, data=soci1, model=TRUE))
summary(vglmFit3a)
anova(vglmFit3a, vglm0, type="I")
AIC(vglmFit3a)

(vglmFit4 <- vglm(pcp_percept_nat_overall ~ wci_max_01+elephant_damage*soc_gender+crop_damage*soc_gender+pre.start.village, family=propodds, data=soci1, model=TRUE))
summary(vglmFit4)
anova(vglmFit4, vglmFit3a, type="I") #ns

